@@ -57,6 +57,7 @@ static const gchar *author_credits[] = {
   "Peter Astrand  <astrand lysator liu se>",
   "Jonathan Blandford  <jrb redhat com>",
   "Paul Bolle  <pebolle tiscali nl>",
+  "Leonardo Boshell  <p kapcoweb com>",
   "Ross Burton  <ross burtonini com>",
   "Damien Carbery  <damien carbery sun com>",
   "Anders Carlsson  <andersca codefactory se>",
@@ -69,12 +70,16 @@ static const gchar *author_credits[] = {
   "Tomasz Koczko  <kloczek pld org pl>",
   "Jordi Mallach  <jordi sindominio net>",
   "Kjartan Maraas  <kmaraas gnome org>",
+  "Breda McColgan  <breda mccolgan sun com>",
+  "Baptiste Mille-Mathias  <bmm80 free fr>",
   "Buhan Milne  <bgmilne linux-mandrake com>",
   "Christian Monneckes  <c-w-m gmx de>",
+  "Ivan Noris  <vix vazka sk>",
   "Havoc Pennington  <hp redhat com>",
   "Jan Arne Petersen  <jpetersen uni-bonn de>",
   "Kevin C  Krinke  <kckrinke opendoorsoftware com>",
   "Kristian Rietveld  <kris gtk org>",
+  "Lucas Rocha  <lucasr im ufba br>",
   "Christian Rose  <menthos menthos com>",
   "Jakub Steiner  <jimmac ximian com>",
   "Luke Suchocki  <gnome lukiepoo com>",
@@ -89,16 +94,21 @@ static const gchar *author_credits[] = {
   "Taneem Ahmed  <taneem bengalinux org>",
   "Takeshi Aihana <aihana gnome gr jp>",
   "Amanpreet Singh Alam  <amanlinux netscape net>",
+  "Metin Amiroff  <metin karegen com>",
   "Sanlig Badral  <badral openmn org>",
+  "John C Barstow  <jbowtie amathaine com>",
   "Aygimantas Beruka  <uid0 tuxfamily org>",
   "Alberto Fernandez Benito <afernn euskalnet net>",
   "Stefano Canepa  <sc linux it>",
   "Young-Ho Cha <ganadist mizi com>",
   "Abel Cheung  <maddog linux org hk>",
   "Zbigniew Chyla  <cyba gnome pl>",
+  "Mohammad Damt  <mdamt bisnisweb com>",
   "Fatih Demir  <kabalak gtranslator org>",
   "Laurent Dhima  <laurenti alblinux net>",
   "Paul Duffy <dubhthach frink nuigalway ie>",
+  "Laszlo Dvornik  <dvornik gnome hu>",
+  "Maxim Dziumanenko  <mvd mylinux com ua>",
   "Francisco Javier Fernandez  <serrador arrakis es>",
   "Artur Flinta  <aflinta cvs gnome org>",
   "Alessio Frusciante  <algol firenze linux it>",
@@ -106,7 +116,9 @@ static const gchar *author_credits[] = {
   "Pablo Gonzalo del Campo  <pablodc bigfoot com>",
   "Dhurba Gnawali  <dhurbagnawali hotmail com>",
   "Sammi Gunnarsson  <sammi techattack nu>",
+  "Martin Willemoes Hansen  <mwh sysrq dk>",
   "Dafydd Harries  <daf parnassus ath cx>",
+  "Raphael Higino  <raphaelh cvs gnome org>",
   "Wang Jian  <lark linux net cn>",
   "Guntupalli Karunakar  <karunakar freedomink org>",
   "Tomas Kuliavas  <tokul users sourceforge net>",
@@ -114,6 +126,7 @@ static const gchar *author_credits[] = {
   "Iaki Larraaga  <dooteo euskalgnu org>",
   "Ole Laursen  <olau hardworking dk>",
   "Toivo Leedjrv  <toivo linux ee>",
+  "David Lodge  <dave cirt net>",
   "Duarte Loreto  <happyguy_pt hotmail com>",
   "Johanna Makkonen  <johanna makkonen iki fi>",
   "Jordi Mallach  <jordi sindominio net>",
@@ -124,19 +137,25 @@ static const gchar *author_credits[] = {
   "Arafat Medini  <lumina silverpen de>",
   "Christophe Merlet  <redfox redfoxcenter org>",
   "Mike Newman  <mikegtn gnome org>",
+  "Ahmad Riza H Nst  <rizahnst eriagempita co id>",
   "Alexandre Folle de Menezes  <afmenez terra com br>",
   "Christian Neumair  <chris gnome-de org>",
   "Metin Omirov  <metin karegen com>",
+  "Gareth Owen  <gowen72 yahoo com>",
   "Kostas Papadimas  <pkst gmx net>",
+  "Ankit Patel  <ankit redhat com>",
   "Sami Pesonen  <sampeson iki fi>",
   "Roozbeh Pournader  <roozbeh sharif edu>",
   "Jarkko Ranta  <jjranta cc joensuu fi>",
+  "Rostislav Raykov  <zbrox dir bg>",
+  "Hendrik Richter  <hendrik gnome de org>",
   "Christian Rose  <menthos menthos com>",
   "Changwoo Ryu  <cwryu debian org>",
   "Pablo Saratxaga  <pablo mandrakesoft com>",
   "Robert Sedak  <robert sedak sk htnet hr>",
   "Paisa Seeluangsawat  <paisa users sf net>",
   "Danilo Segan  <dsegan gmx net>",
+  "Alexander Shopov  <ash contact bg>",
   "Aasmund Skjaveland  <aasmunds fys uio no>",
   "Yuriy Syrota  <rasta renome rovno ua>",
   "Marcel Telka  <marcel telka sk>",
@@ -281,7 +300,7 @@ zenity_create_boutique (void)
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
-  zenity_util_set_window_icon (window, ZENITY_IMAGE_FULLPATH ("zenity.png"));
+  zenity_util_set_window_icon (window, NULL, ZENITY_IMAGE_FULLPATH ("zenity.png"));
   canvas = zenity_create_monk ();
   gtk_container_add (GTK_CONTAINER (window), canvas);
 
@@ -345,7 +364,15 @@ zenity_about (ZenityData *data)
     return;
   }
 
-  translator_credits = _("translator_credits");
+  /* Translators: This is a special message that shouldn't be translated
+                  literally. It is used in the about box to give credits to
+                  the translators.
+                  Thus, you should translate it to your name and email address.
+                  You can also include other translators who have contributed to
+                  this translation; in that case, please write them on separate
+                  lines seperated by newlines (\n). */
+
+  translator_credits = _("translator-credits");
 
   glade_xml_signal_autoconnect (glade_dialog);
 
@@ -356,7 +383,7 @@ zenity_about (ZenityData *data)
   g_signal_connect (G_OBJECT (dialog), "key_press_event",
                     G_CALLBACK (zenity_zen_wisdom), glade_dialog);
 
-  zenity_util_set_window_icon (dialog, ZENITY_IMAGE_FULLPATH ("zenity.png"));
+  zenity_util_set_window_icon (dialog, NULL, ZENITY_IMAGE_FULLPATH ("zenity.png"));
 
   image = glade_xml_get_widget (glade_dialog, "zenity_about_image");
 
@@ -435,7 +462,7 @@ zenity_about_update_translator_label (GtkWidget *label)
   GString *string;
   gchar *tmp;
 
-  if (strcmp (translator_credits, "translator_credits") == 0) {
+  if (strcmp (translator_credits, "translator-credits") == 0) {
     gtk_widget_hide (label);
     return;
   } else {
@@ -494,7 +521,7 @@ zenity_about_display_credits_dialog (void)
     zenity_about_update_author_label (label);
   }
 
-  if (translator_credits != NULL && strcmp (translator_credits, "translator_credits") != 0) {
+  if (translator_credits != NULL && strcmp (translator_credits, "translator-credits") != 0) {
     label = zenity_about_create_label ();
     sw = gtk_scrolled_window_new (NULL, NULL);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), 
