@@ -58,10 +58,7 @@ zenity_calendar (ZenityData *data, ZenityCalendarData *cal_data)
   if (data->dialog_title)	
     gtk_window_set_title (GTK_WINDOW (dialog), data->dialog_title);
 
-  if (data->window_icon)
-    zenity_util_set_window_icon (dialog, data->window_icon);
-  else
-    zenity_util_set_window_icon (dialog, ZENITY_IMAGE_FULLPATH ("zenity-calendar.png"));
+  zenity_util_set_window_icon (dialog, data->window_icon, ZENITY_IMAGE_FULLPATH ("zenity-calendar.png"));
 
   if (data->width > -1 || data->height > -1)
     gtk_window_set_default_size (GTK_WINDOW (dialog), data->width, data->height);
@@ -76,7 +73,7 @@ zenity_calendar (ZenityData *data, ZenityCalendarData *cal_data)
   if (glade_dialog)
     g_object_unref (glade_dialog);
 
-  if (cal_data->month > 0 && cal_data->year > 0)
+  if (cal_data->month > 0 || cal_data->year > 0)
     gtk_calendar_select_month (GTK_CALENDAR (calendar), cal_data->month - 1, cal_data->year);
   if (cal_data->day > 0)
     gtk_calendar_select_day (GTK_CALENDAR (calendar), cal_data->day);
