@@ -15,10 +15,14 @@ GladeXML*       zenity_util_load_glade_file               (const gchar    *widge
 gchar *         zenity_util_strip_newline                 (gchar          *string);
 gboolean        zenity_util_fill_file_buffer              (GtkTextBuffer  *buffer, 
                                                            const gchar    *filename);
-void            zenity_util_set_window_icon               (GtkWidget      *widget,
-                                                           const gchar    *filename);
+void		zenity_util_set_window_icon		  (GtkWidget      *widget,
+							   const gchar	  *filename,
+							   const gchar	  *default_file);
 void            zenity_util_set_window_icon_from_stock    (GtkWidget      *widget,
-                                                           const gchar    *stock_id);
+							   const gchar    *filename,
+                                                           const gchar    *default_stock_id);
+GdkPixbuf *	zenity_util_pixbuf_new_from_file	  (GtkWidget	  *widget,
+							   gchar	  *filename);
 void		zenity_util_show_help                     (GError        **error);
 gint		zenity_util_return_exit_code 		  (ZenityExitCode value);                      
 void            zenity_util_show_dialog                   (GtkWidget      *widget);
